@@ -20,14 +20,6 @@ from blockdiag.elements import *
 from blockdiag.utils.XY import XY
 
 
-class Diagram(blockdiag.elements.Diagram):
-    def __init__(self):
-        super(Diagram, self).__init__()
-
-        self.orientation = 'portrait'
-        self.lanes = []
-
-
 class DiagramNode(blockdiag.elements.DiagramNode):
     def __init__(self, id):
         super(DiagramNode, self).__init__(id)
@@ -40,3 +32,14 @@ class NodeGroup(blockdiag.elements.NodeGroup):
         super(NodeGroup, self).__init__(id)
 
         self.color = 'none'
+
+
+class Diagram(blockdiag.elements.Diagram):
+    _DiagramNode = DiagramNode
+    _NodeGroup = NodeGroup
+
+    def __init__(self):
+        super(Diagram, self).__init__()
+
+        self.orientation = 'portrait'
+        self.lanes = []
